#
# spec file for package openstack-monasca-agent
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global sname monasca-agent
%define username            monasca-agent
%define groupname           monasca
%if 0%{?rhel} || 0%{?fedora}
%global rdo 1
%endif
Name:           openstack-monasca-agent
Version:        2.2.5~dev2
Release:        2.1
Summary:        OpenStack Monasca metrics agent
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            https://wiki.openstack.org/wiki/Monasca
Source0:        monasca-agent-stable-pike.tar.gz
Source1:        %{name}-sudoers
Source2:        %{name}.service
Source3:        %{name}.tmpfiles
Source4:        %{name}.polkit
Patch1:         libvirt-aggregate-status.patch
Patch2:         monitor-cassandra-538096.patch
Patch3:         0001-Avoid-overwriting-sys.path-ip-command.patch
BuildRequires:  openstack-macros
BuildRequires:  python-PyYAML
BuildRequires:  python-devel
BuildRequires:  python-futures
BuildRequires:  python-gevent
BuildRequires:  python-httplib2
BuildRequires:  python-mock
BuildRequires:  python-monascaclient
BuildRequires:  python-netaddr
BuildRequires:  python-ntplib
BuildRequires:  python-os-testr
BuildRequires:  python-oslo.concurrency
BuildRequires:  python-oslo.config
BuildRequires:  python-oslo.i18n
BuildRequires:  python-oslo.middleware
BuildRequires:  python-oslo.utils
BuildRequires:  python-oslo.vmware
BuildRequires:  python-oslotest
BuildRequires:  python-psutil
BuildRequires:  python-pymongo
BuildRequires:  python-python-memcached
BuildRequires:  python-redis
BuildRequires:  python-requests
BuildRequires:  python-stevedore
BuildRequires:  python-supervisor
BuildRequires:  python-tornado
BuildRequires:  sudo
Requires:       python-%{sname} = %{version}-%{release}
BuildArch:      noarch
%if 0%{?suse_version}
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}
%else
BuildRequires:  systemd
Requires(post): systemd
Requires(postun):   systemd
Requires(preun):    systemd
%endif

%description
The Monasca Agent is a modern Python monitoring agent for gathering metrics and
sending them to the Monasca API.

%package -n python-%{sname}
Summary:        Python module for monasca-agent
Group:          Development/Languages/Python
Requires:       python-PyYAML
Requires:       python-futures
Requires:       python-gevent
Requires:       python-httplib2
Requires:       python-monascaclient
Requires:       python-netaddr
Requires:       python-ntplib
Requires:       python-oslo.concurrency
Requires:       python-oslo.config
Requires:       python-oslo.i18n
Requires:       python-oslo.middleware
Requires:       python-oslo.utils
Requires:       python-oslo.vmware
Requires:       python-psutil
Requires:       python-pymongo
Requires:       python-python-memcached
Requires:       python-redis
Requires:       python-requests
Requires:       python-stevedore
Requires:       python-supervisor
# FIXME(jpena): Remove this conditional once python-toml is available in RDO
%if 0%{?rdo}
Requires:       python-tornado
%else
Requires:       python-toml
Requires:       python-tornado
%endif

%description -n python-%{sname}
The Monasca Agent is a modern Python monitoring agent for gathering metrics and
sending them to the Monasca API.

This package contains monasca-agent Python module.

%prep
%autosetup -p 1 -n %{sname}-2.2.5.dev2
%py_req_cleanup
# contains various binary files etc that we don't need
rm -rf packaging/monasca-agent{,-deb}

%build
%py2_build

%install
%py2_install

# /etc
install -d -m 755 %{buildroot}%{_sysconfdir}/monasca
install -d -m 750 %{buildroot}%{_sysconfdir}/monasca/agent/conf.d

# /usr/lib
install -d -m 750 %{buildroot}%{_prefix}/lib/monasca/agent/custom_checks.d
install -d -m 750 %{buildroot}%{_prefix}/lib/monasca/agent/custom_detect.d

# /var
install -d -m 750  %{buildroot}%{_localstatedir}/log/%{sname}

# sudoers configuration
install -D -m 440 %{SOURCE1} %{buildroot}%{_sysconfdir}/sudoers.d/%{name}

# systemd unit file
install -D -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service
%if 0%{?suse_version}
mkdir -p %{buildroot}%{_sbindir}
ln -sr %{buildroot}%{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
%endif

# systemd tmpfile
install -D -m 644 %{SOURCE3} %{buildroot}%{_tmpfilesdir}/openstack-monasca-agent.conf

# polkit permissions
install -D -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/polkit-1/rules.d/49-monasca-agent.rules

%pre
# create user and groups
%openstack_pre_user_group_create %{username} %{groupname}

%post
%tmpfiles_create %{_tmpfilesdir}/openstack-monasca-agent.conf
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%postun
%systemd_postun %{name}.service

%check
find . -type f -name *.pyc -delete
find . -type f -name '*test_service_plugin.py' -delete
python setup.py test

%files
%dir %attr(-, root, monasca) %{_sysconfdir}/monasca
%dir %attr(0750, %{username}, %{groupname}) %{_sysconfdir}/monasca/agent
%dir %attr(0750, %{username}, %{groupname}) %{_sysconfdir}/monasca/agent/conf.d
%_tmpfilesdir/openstack-monasca-agent.conf
%config %{_sysconfdir}/monasca/agent
%config %{_sysconfdir}/sudoers.d/%{name}
%dir %{_prefix}/lib/monasca
%{_prefix}/lib/monasca/agent
%dir %attr(0750, %{username}, %{groupname}) %{_localstatedir}/log/%{sname}
%{_unitdir}/%{name}.service
%if 0%{?suse_version}
%{_sbindir}/rc%{name}
%endif
%{_sysconfdir}/polkit-1/
%{_sysconfdir}/polkit-1/rules.d/
%{_sysconfdir}/polkit-1/rules.d/49-monasca-agent.rules

%files -n python-%{sname}
%doc README.md
%license LICENSE
%{_bindir}/monasca-collector
%{_bindir}/monasca-forwarder
%{_bindir}/monasca-setup
%{_bindir}/monasca-statsd
%{python2_sitelib}/monasca_agent
%{python2_sitelib}/monasca_agent-*.egg-info
%{python2_sitelib}/monasca_setup
%dir %{_datadir}/monasca
%{_datadir}/monasca/agent

%changelog
